@@ -51,9 +51,10 @@ recMissComp <- function(Experiment, min.samples, free.model=F)
 			sampleRD@min.peak.height <- Experiment@Data@Parameters$min.peak.height
 			#sampleRD@factor.minimum.sd <- Experiment@Data@Parameters$factor.minimum.sd 
 			
-			avoid.mz <- sampleRD@avoid.processing.mz - (sampleRD@min.mz - 1)
-			avoid.mz <- avoid.mz[-which(avoid.mz<1)]
-			sampleRD@data[,avoid.mz] <- 0
+			#avoid.mz <- sampleRD@avoid.processing.mz - (sampleRD@min.mz - 1)
+			#avoid.mz <- avoid.mz[-which(avoid.mz<1)]
+			#sampleRD@data[,avoid.mz] <- 0
+			sampleRD <- avoid.processing(sampleRD)
 	
 			moving.maximas <- apply(sampleRD@data,2,function(x){max(x)})
 			sampleRD@data[,moving.maximas<sampleRD@noise.threshold] <- 0
